@@ -19,6 +19,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
  */
+using namespace std;
 
 #include "cache.h"
 #include "dialogprogress.h"
@@ -30,6 +31,7 @@
 #include <signal.h>
 #include <errno.h>
 
+
 static string broken_string(GAptCache* cache);
 static string stats_string(GAptCache* cache);
 
@@ -85,8 +87,8 @@ gnome_apt_cache_file_shutdown()
   cf = 0;
 }
 
-GAptCache::GAptCache(MMap & Map, OpProgress &Prog)
-  : pkgDepCache(Map,Prog)
+GAptCache::GAptCache(pkgCache *pCache)
+  : pkgDepCache(pCache)
 {
 
 }
@@ -130,10 +132,17 @@ GAptCacheFile::Open()
   }
   else {
     progressmessage = _("Creating Apt's Package Cache File");
+    // This is here to prevent double-locking when reopening the cache
+    // file
+    if (_system->Lock() == false)
+      return false;
   }
 
   // Create a progress class
   OpDialogProgress* Progress = new OpDialogProgress(progressmessage.c_str());
+
+  if (_error->PendingError() == true)
+    return false;
       
   // Read the source list
   pkgSourceList List;
@@ -161,8 +170,15 @@ GAptCacheFile::Open()
     map_ = 0;
     return false;
   }
-   
-  cache_ = new GAptCache(*map_,*Progress);
+
+  pkgCache *pkgcache = new pkgCache(map_);
+  if (_error->PendingError() == true) {
+    delete pkgcache;
+    return false;
+  }
+
+  cache_ = new GAptCache(pkgcache);
+  cache_->Init(Progress);
   if (_error->PendingError() == true) {
     delete cache_;
     cache_ = 0;
@@ -176,7 +192,9 @@ GAptCacheFile::Open()
 
    // Check that the system is OK
   if (cache_->DelCount() != 0 || cache_->InstCount() != 0)
-    return _error->Error("Internal Error, non-zero counts");
+    return _error->Error("Internal Error, non-zero counts"
+                         " (del count %ld, inst count %ld)",
+                         cache_->DelCount(), cache_->InstCount());
    
    // Apply corrections for half-installed packages
   if (pkgApplyStatus(*cache_) == false)
@@ -319,14 +337,8 @@ GAptCacheFile::UpdateAndReopen()
   pkgAcquire Fetcher(&Stat);
    
    // Populate it with the source selection
-  pkgSourceList::const_iterator I;
-  for (I = List.begin(); I != List.end(); I++)
-    {
-      // FIXME memory leak??? It must be... when can I delete?
-      new pkgAcqIndex(&Fetcher,I);
-      if (_error->PendingError() == true)
-        return false;
-    }
+  if (List.GetIndexes(&Fetcher) == false)
+    return false;
    
   // Run it
   pkgAcquire::RunResult res = Fetcher.Run();
@@ -428,12 +440,12 @@ Preview::confirm()
   // Check for removing essential
   pkgCache::PkgIterator i = cache_->PkgBegin();
   string essential;
-  bool *added = new bool[cache_->HeaderP->PackageCount];
+  bool *added = new bool[cache_->Head().PackageCount];
 
   // Set whole array to false
   memset(static_cast<void*>(added), 
          '\0', 
-         cache_->HeaderP->PackageCount*sizeof(bool)); 
+         cache_->Head().PackageCount*sizeof(bool)); 
 
   while (!i.end())
     {
@@ -460,7 +472,7 @@ Preview::confirm()
         }
       
       // Print out any essential package depenendents that are to be removed
-      pkgDepCache::DepIterator d = i.CurrentVer().DependsList();
+      pkgCache::DepIterator d = i.CurrentVer().DependsList();
       while (!d.end())
         {
           // Skip everything but depends
@@ -608,7 +620,7 @@ GAptCacheFile::Install()
       // Run the simulator ..
       if (_config->FindB("APT::Gnome::Simulate") == true)
         {
-          pkgSimulate PM(*cache_);
+          pkgSimulate PM(cache_);
           return PM.DoInstall();
         }
 
@@ -635,13 +647,13 @@ GAptCacheFile::Install()
         return _error->Error(_("The list of sources could not be read."));
    
       // Create the package manager and prepare to download
-      pkgDPkgPM PM(*cache_);
+      pkgDPkgPM PM(cache_);
       if (PM.GetArchives(&Fetcher,&List,&Recs) == false)
         return false;
 
       // Display statistics
-      unsigned long FetchBytes = Fetcher.FetchNeeded();
-      unsigned long DebBytes = Fetcher.TotalNeeded();
+      double FetchBytes = Fetcher.FetchNeeded();
+      double DebBytes = Fetcher.TotalNeeded();
       if (DebBytes != cache_->DebSize())
         {
           cerr << DebBytes << ',' << cache_->DebSize() << endl;
@@ -654,21 +666,21 @@ GAptCacheFile::Install()
 
       // Number of bytes
       if (DebBytes != FetchBytes)
-        g_snprintf(buf, 511, _("Need to get %s/%s of archives\n"), 
+        g_snprintf(buf, 511, _("Need to get %sB/%sB of archives\n"), 
                    SizeToStr(FetchBytes).c_str(),
                    SizeToStr(DebBytes).c_str());
       else
-        g_snprintf(buf, 511, _("Need to get %s of archives\n"), 
+        g_snprintf(buf, 511, _("Need to get %sB of archives\n"), 
                    SizeToStr(DebBytes).c_str());
       
       confirm += buf;
 
       // Size delta
       if (cache_->UsrSize() >= 0)
-        g_snprintf(buf, 511, _("%s will be used\n"),
+        g_snprintf(buf, 511, _("%sB will be used\n"),
                    SizeToStr(cache_->UsrSize()).c_str());
       else
-        g_snprintf(buf, 511, _("%s will be freed\n"),
+        g_snprintf(buf, 511, _("%sB will be freed\n"),
                    SizeToStr(-1*cache_->UsrSize()).c_str());
 
       confirm += buf;
@@ -711,7 +723,7 @@ GAptCacheFile::Install()
       string errors;
 
       // Print out errors
-      pkgAcquire::Item **i = Fetcher.ItemsBegin(); 
+      vector<pkgAcquire::Item*>::iterator i = Fetcher.ItemsBegin(); 
       while (i != Fetcher.ItemsEnd())
         {
           if ((*i)->Status == pkgAcquire::Item::StatDone &&
@@ -756,7 +768,7 @@ GAptCacheFile::Install()
                      _("Interact with the package installer in the window below."));
 
       // Give up the lock on the cache, just while the child is running
-      Lock.Close();
+      _system->UnLock();
 
       int pid = cd.fork();
       switch (pid) {
@@ -821,7 +833,7 @@ GAptCacheFile::Install()
           bool retval = cd.run();
           
           // get lock back
-          if (Lock.GetLock(true) == false)
+          if (_system->Lock() == false)
             gnome_apt_fatal_dialog(_("Failed to get the lock back from dpkg"));
 
    
@@ -872,7 +884,7 @@ GAptCacheFile::SmartMarkUpgrades()
 void
 GAptCacheFile::Fix()
 {
-  pkgProblemResolver fixer(*cache_);
+  pkgProblemResolver fixer(cache_);
 
   fixer.InstallProtect();
   if (fixer.Resolve(true) == false)
