@@ -52,7 +52,7 @@ static void priority_group_cb     (GtkWidget* w, gpointer data);
 
 // File
 static void apt_prefs_cb   (GtkWidget* w, gpointer data);
-static void sources_cb     (GtkWidget* w, gpointer data);
+/* static void sources_cb     (GtkWidget* w, gpointer data); */
 static void exit_cb        (GtkWidget* w, gpointer data);
 
 // Actions
@@ -85,43 +85,43 @@ static GnomeUIInfo columns_menu[] = {
 #define COLUMNS_NAME 0
   {GNOME_APP_UI_TOGGLEITEM, N_("Package Name"), 
    N_("Whether to show the package name column"),
-   name_column_cb, NULL, NULL,
+   (gpointer)name_column_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define COLUMNS_CURRENT 1
   {GNOME_APP_UI_TOGGLEITEM, N_("Installed Version"), 
    N_("Whether to show the installed version column"),
-   installed_column_cb, NULL, NULL,
+   (gpointer)installed_column_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define COLUMNS_AVAILABLE 2
   {GNOME_APP_UI_TOGGLEITEM, N_("Available Version"), 
    N_("Whether to show the available version column"),
-   available_column_cb, NULL, NULL,
+   (gpointer)available_column_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define COLUMNS_SECTION 3
   {GNOME_APP_UI_TOGGLEITEM, N_("Package Section"), 
    N_("Whether to show the package section column"),
-   section_column_cb, NULL, NULL,
+   (gpointer)section_column_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define COLUMNS_PRIORITY 4
   {GNOME_APP_UI_TOGGLEITEM, N_("Package Priority"), 
    N_("Whether to show the package priority column"),
-   priority_column_cb, NULL, NULL,
+   (gpointer)priority_column_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define COLUMNS_STATUS 5
   {GNOME_APP_UI_TOGGLEITEM, N_("Package Status"), 
    N_("Whether to show the package status column"),
-   status_column_cb, NULL, NULL,
+   (gpointer)status_column_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define COLUMNS_DESCRIPTION 6
   {GNOME_APP_UI_TOGGLEITEM, N_("Description"), 
    N_("Whether to show the package description column"),
-   description_column_cb, NULL, NULL,
+   (gpointer)description_column_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
   GNOMEUIINFO_END
@@ -131,25 +131,25 @@ static GnomeUIInfo order_items[] = {
 #define ORDERS_ALPHA 0
   {GNOME_APP_UI_ITEM, N_("Alphabetical"), 
    N_("Show packages in alphabetical order"),
-   alpha_order_cb, NULL, NULL,
+   (gpointer)alpha_order_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define ORDERS_SECTION 1
   {GNOME_APP_UI_ITEM, N_("By section"), 
    N_("Show sections together"),
-   section_order_cb, NULL, NULL,
+   (gpointer)section_order_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define ORDERS_STATUS 2
   {GNOME_APP_UI_ITEM, N_("By status"), 
    N_("Show packages with the same status together"),
-   status_order_cb, NULL, NULL,
+   (gpointer)status_order_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define ORDERS_PRIORITY 3
   {GNOME_APP_UI_ITEM, N_("By priority"), 
    N_("Show packages with the same priority together"),
-   priority_order_cb, NULL, NULL,
+   (gpointer)priority_order_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
   // FIXME
@@ -166,25 +166,25 @@ static GnomeUIInfo group_items[] = {
 #define GROUP_ALPHA 0
   {GNOME_APP_UI_ITEM, N_("Alphabetical"), 
    N_("Show packages in alphabetical order"),
-   alpha_group_cb, NULL, NULL,
+   (gpointer)alpha_group_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define GROUP_SECTION 1
   {GNOME_APP_UI_ITEM, N_("By section"), 
    N_("Show sections together"),
-   section_group_cb, NULL, NULL,
+   (gpointer)section_group_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define GROUP_STATUS 2
   {GNOME_APP_UI_ITEM, N_("By status"), 
    N_("Show packages with the same status together"),
-   status_group_cb, NULL, NULL,
+   (gpointer)status_group_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 #define GROUP_PRIORITY 3
   {GNOME_APP_UI_ITEM, N_("By priority"), 
    N_("Show packages with the same priority together"),
-   priority_group_cb, NULL, NULL,
+   (gpointer)priority_group_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
   // FIXME
@@ -201,27 +201,27 @@ static GnomeUIInfo popup_menu[] = {
 #define POPUP_REMOVE 1
   {GNOME_APP_UI_ITEM, N_("Delete"), 
    N_("Mark this package to be removed (preserve configuration files)"),
-   remove_pkg_cb, NULL, NULL,
+   (gpointer)remove_pkg_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 
 #define POPUP_KEEP 2
   {GNOME_APP_UI_ITEM, N_("Keep"), 
    N_("Keep the currently selected package"),
-   keep_pkg_cb, NULL, NULL,
+   (gpointer)keep_pkg_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 
 #define POPUP_INSTALL 3
   {GNOME_APP_UI_ITEM, N_("Install/upgrade"), 
    N_("Mark this package to be installed"),
-   install_pkg_cb, NULL, NULL,
+   (gpointer)install_pkg_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
 
   {GNOME_APP_UI_ITEM, N_("Search..."), 
    N_("Find a package by name or other criteria"),
-   search_cb, NULL, NULL,
+   (gpointer)search_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH, '\0', 
    (GdkModifierType)0, NULL },  
 
@@ -236,7 +236,7 @@ static GnomeUIInfo popup_menu[] = {
 static GnomeUIInfo view_menu[] = {
   {GNOME_APP_UI_ITEM, N_("Details..."), 
    N_("Show package information in a separate window"),
-   details_cb, NULL, NULL,
+   (gpointer)details_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_OPEN, 'D', 
    (GdkModifierType)GDK_CONTROL_MASK, NULL },
 
@@ -251,18 +251,18 @@ static GnomeUIInfo view_menu[] = {
 static GnomeUIInfo file_menu[] = {
   {GNOME_APP_UI_ITEM, N_("General _preferences..."), 
    N_("Change general Apt preferences"),
-   apt_prefs_cb, NULL, NULL,
+   (gpointer)apt_prefs_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF,  '\0', 
    (GdkModifierType)0, NULL },
-  {GNOME_APP_UI_ITEM, N_("_Sources..."), 
+  /*  {GNOME_APP_UI_ITEM, N_("_Sources..."), 
    N_("Choose where Apt looks for packages"),
-   sources_cb, NULL, NULL,
+   (gpointer)sources_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF, '\0', 
-   (GdkModifierType)0, NULL },
+   (GdkModifierType)0, NULL }, */
   GNOMEUIINFO_SEPARATOR,
   {GNOME_APP_UI_ITEM, N_("_Exit"), 
    N_("Quit the application"),
-   exit_cb, NULL, NULL,
+   (gpointer)exit_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 
    GNOME_KEY_NAME_EXIT, GNOME_KEY_MOD_EXIT,
    NULL },
@@ -272,28 +272,28 @@ static GnomeUIInfo file_menu[] = {
 static GnomeUIInfo actions_menu[] = {
   {GNOME_APP_UI_ITEM, N_("_Update"), 
    N_("Update the package list from chosen sources"),
-   update_cb, NULL, NULL,
+   (gpointer)update_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REFRESH, 'U', 
    (GdkModifierType)GDK_CONTROL_MASK, NULL },
 
   {GNOME_APP_UI_ITEM, N_("_Complete run"), 
    N_("Install, remove, and delete packages as requested."),
-   complete_run_cb, NULL, NULL,
+   (gpointer)complete_run_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXEC, 'R', 
    (GdkModifierType)GDK_CONTROL_MASK, NULL },
   {GNOME_APP_UI_ITEM, N_("Mark _Upgrades"), 
    N_("Mark all out-of-date packages for upgrade, without removals or installs."),
-   upgrade_cb, NULL, NULL,
+   (gpointer)upgrade_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
   {GNOME_APP_UI_ITEM, N_("_Smart Mark Upgrades"), 
    N_("Mark upgrades, removing or installing packages if needed."),
-   smart_upgrade_cb, NULL, NULL,
+   (gpointer)smart_upgrade_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
   {GNOME_APP_UI_ITEM, N_("_Fix Broken"), 
    N_("Fix broken packages, removing or installing packages if needed."),
-   fix_broken_cb, NULL, NULL,
+   (gpointer)fix_broken_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, 'F', 
    (GdkModifierType)GDK_CONTROL_MASK, NULL },
   GNOMEUIINFO_END
@@ -302,25 +302,25 @@ static GnomeUIInfo actions_menu[] = {
 static GnomeUIInfo package_menu[] = {
   {GNOME_APP_UI_ITEM, N_("Search..."), 
    N_("Find a package by name or other criteria"),
-   search_cb, NULL, NULL,
+   (gpointer)search_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH, 'S', 
    (GdkModifierType)GDK_CONTROL_MASK, NULL },  
 #define PACKAGE_REMOVE 1
   {GNOME_APP_UI_ITEM, N_("_Delete"), 
    N_("Uninstall package, keeping configuration."),
-   remove_pkg_cb, NULL, NULL,
+   (gpointer)remove_pkg_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, 'D', 
    (GdkModifierType)0, NULL },
 #define PACKAGE_KEEP 2
   {GNOME_APP_UI_ITEM, N_("_Keep"), 
    N_("Don't change this package."),
-   keep_pkg_cb, NULL, NULL,
+   (gpointer)keep_pkg_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, 'K', 
    (GdkModifierType)0, NULL },
 #define PACKAGE_INSTALL 3
   {GNOME_APP_UI_ITEM, N_("_Install/Upgrade"), 
    N_("Install this package."),
-   install_pkg_cb, NULL, NULL,
+   (gpointer)install_pkg_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, 'I', 
    (GdkModifierType)0, NULL },
   GNOMEUIINFO_END
@@ -330,17 +330,17 @@ static GnomeUIInfo package_menu[] = {
 static GnomeUIInfo advanced_menu[] = {
   {GNOME_APP_UI_ITEM, N_("_Export packagelist..."), 
    N_("Save the current state of the package list to disk for use on another system."),
-   export_cb, NULL, NULL,
+   (gpointer)export_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, '\0', 
    (GdkModifierType)0, NULL },
   {GNOME_APP_UI_ITEM, N_("_Import packagelist..."), 
    N_("Load a package list."),
-   import_cb, NULL, NULL,
+   (gpointer)import_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, '\0', 
    (GdkModifierType)0, NULL },
   {GNOME_APP_UI_ITEM, N_("_Bug report..."), 
    N_("File a bug against this package."),
-   bug_cb, NULL, NULL,
+   (gpointer)bug_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0', 
    (GdkModifierType)0, NULL },
   GNOMEUIINFO_END
@@ -350,12 +350,12 @@ static GnomeUIInfo help_menu[] = {
   GNOMEUIINFO_HELP(const_cast<char*>(APPNAME)),
   {GNOME_APP_UI_ITEM, N_("_About..."), 
    N_("Tell about this application"), 
-   about_cb, NULL, NULL,
+   (gpointer)about_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, '\0',  
    (GdkModifierType)0, NULL },
   {GNOME_APP_UI_ITEM, N_("_Icon Key"), 
    N_("Explain what all the icons in the tree view mean."), 
-   icons_cb, NULL, NULL,
+   (gpointer)icons_cb, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL, '\0',  
    (GdkModifierType)0, NULL },
   GNOMEUIINFO_END
@@ -366,7 +366,8 @@ static GnomeUIInfo main_menu[] = {
   GNOMEUIINFO_SUBTREE (N_("_Actions"), actions_menu),
   GNOMEUIINFO_SUBTREE (N_("_Package"), package_menu),
   GNOMEUIINFO_SUBTREE (N_("_View"), view_menu),
-  GNOMEUIINFO_SUBTREE (N_("A_dvanced"), advanced_menu),
+  /* doesn't work yet */
+  //  GNOMEUIINFO_SUBTREE (N_("A_dvanced"), advanced_menu),
   GNOMEUIINFO_SUBTREE (N_("_Help"), help_menu),
   GNOMEUIINFO_END
 };
@@ -1128,6 +1129,7 @@ apt_prefs_cb   (GtkWidget* w, gpointer data)
   gnome_apt_preferences()->edit();
 }
 
+/*
 static void
 sources_cb     (GtkWidget* w, gpointer data)
 {
@@ -1135,6 +1137,7 @@ sources_cb     (GtkWidget* w, gpointer data)
 
   gnome_apt_sources()->edit();
 }
+*/
 
 static void
 exit_cb        (GtkWidget* w, gpointer data)
