@@ -19,6 +19,8 @@
  * USA
  */
 
+using namespace std;
+
 #include "pkgtree.h"
 
 #include "pkgutil.h"
@@ -30,6 +32,7 @@
 
 #include <gdk/gdkkeysyms.h>
 
+
 ////////////////////////
 /// some utility gibberish
 
@@ -462,6 +465,7 @@ GAptPkgTree::type_column(ColumnType col) const
     ++i;
   }
   g_return_val_if_fail(0,0); // warn and return 0
+return 0;
 }
 
 static const char* 
@@ -541,6 +545,9 @@ public:
   bool operator() (pred_target a, pred_target b) {
     return (strcmp(a->name(),b->name()) < 0);
   }
+  bool operator() (DrawTree::Node* a, DrawTree::Node* b) {
+	  return operator() (dynamic_cast<pred_target>(a), dynamic_cast<pred_target>(b));
+  }
     
 } name_predicate;
 
@@ -556,6 +563,9 @@ public:
     else if (bs == 0) return true;      // b > a
     else return (strcmp(as, bs) < 0);
   }
+  bool operator() (DrawTree::Node* a, DrawTree::Node* b) {
+	  return operator() (dynamic_cast<pred_target>(a), dynamic_cast<pred_target>(b));
+  }
 
 } section_predicate;
 
@@ -566,6 +576,9 @@ public:
     //  and the speed benefit is not user visible
     return (strcmp(a->priority(), b->priority()) < 0);
   }
+  bool operator() (DrawTree::Node* a, DrawTree::Node* b) {
+	  return operator() (dynamic_cast<pred_target>(a), dynamic_cast<pred_target>(b));
+  }
 } priority_predicate;
 
 
@@ -574,6 +587,9 @@ public:
   bool operator() (pred_target a, pred_target b) {
     return (a->status() < b->status());
   }
+  bool operator() (DrawTree::Node* a, DrawTree::Node* b) {
+	  return operator() (dynamic_cast<pred_target>(a), dynamic_cast<pred_target>(b));
+  }
 } status_predicate;
 
 //// 
@@ -586,6 +602,10 @@ public:
     return a->filter(filter_);
   }  
 
+  bool operator() (DrawTree::Node* a) {
+	  return operator() (dynamic_cast<pred_target>(a));
+  }
+
 private:
   Filter* filter_;
 
@@ -949,8 +969,8 @@ GAptPkgTree::create_category(CategoryType ct)
         ++i;
       } 
 
-      std::stable_sort((vector<Item*>::iterator)category_list_->begin(), 
-                       (vector<Item*>::iterator)category_list_->end(), 
+      std::stable_sort((vector<DrawTree::Node*>::iterator)category_list_->begin(), 
+                       (vector<DrawTree::Node*>::iterator)category_list_->end(), 
                        name_predicate);
     }
     break; // Alpha end
@@ -995,8 +1015,8 @@ GAptPkgTree::create_category(CategoryType ct)
         ++i;
       }
 
-      std::stable_sort((vector<Item*>::iterator)category_list_->begin(), 
-                       (vector<Item*>::iterator)category_list_->end(), 
+      std::stable_sort((vector<DrawTree::Node*>::iterator)category_list_->begin(), 
+                       (vector<DrawTree::Node*>::iterator)category_list_->end(), 
                        section_predicate);
     }
     break; // Section end
@@ -1037,8 +1057,8 @@ GAptPkgTree::create_category(CategoryType ct)
         
         ++i;
       }
-      std::stable_sort((vector<Item*>::iterator)category_list_->begin(), 
-                       (vector<Item*>::iterator)category_list_->end(), 
+      std::stable_sort((vector<DrawTree::Node*>::iterator)category_list_->begin(), 
+                       (vector<DrawTree::Node*>::iterator)category_list_->end(), 
                        priority_predicate);
     }
     break; // Priority end
@@ -1073,8 +1093,8 @@ GAptPkgTree::create_category(CategoryType ct)
         
         ++i;
       }
-      std::stable_sort((vector<Item*>::iterator)category_list_->begin(), 
-                       (vector<Item*>::iterator)category_list_->end(), 
+      std::stable_sort((vector<DrawTree::Node*>::iterator)category_list_->begin(), 
+                       (vector<DrawTree::Node*>::iterator)category_list_->end(), 
                        status_predicate);
     }
     break; // Status end
@@ -1221,8 +1241,8 @@ GAptPkgTree::Item::sort(GAptPkgTree::SortType st)
 {
   if (children_.empty()) return; // minor optimization
 
-  vector<Item*>::iterator b = reinterpret_cast<vector<Item*>::iterator>(children_.begin());
-  vector<Item*>::iterator e = reinterpret_cast<vector<Item*>::iterator>(children_.end());
+  vector<DrawTree::Node*>::iterator b = reinterpret_cast<vector<DrawTree::Node*>::iterator>(children_.begin());
+  vector<DrawTree::Node*>::iterator e = reinterpret_cast<vector<DrawTree::Node*>::iterator>(children_.end());
 
   switch (st) {
   case SortAlpha:
@@ -1386,10 +1406,10 @@ GAptPkgTree::Category::filter(Filter* filter)
 {  
   if (filter == 0) return true;
 
-  vector<Item*>::iterator b = 
-    reinterpret_cast<vector<Item*>::iterator>(children_.begin());
-  vector<Item*>::iterator e = 
-    reinterpret_cast<vector<Item*>::iterator>(children_.end());
+  vector<DrawTree::Node*>::iterator b = 
+    reinterpret_cast<vector<DrawTree::Node*>::iterator>(children_.begin());
+  vector<DrawTree::Node*>::iterator e = 
+    reinterpret_cast<vector<DrawTree::Node*>::iterator>(children_.end());
   
   FilterPredicate fp(filter);
   
@@ -1976,7 +1996,7 @@ GAptPkgTree::CategoryList::CategoryList(GAptPkgTree* tree)
 
 GAptPkgTree::CategoryList::~CategoryList()
 {
-  vector<Item*>::iterator j = nodes_.begin();
+  vector<DrawTree::Node*>::iterator j = nodes_.begin();
   while (j != nodes_.end()) {
     delete *j;
     ++j;
@@ -2008,7 +2028,7 @@ void
 GAptPkgTree::CategoryList::remove_node(Item* node)
 {
   g_return_if_fail(node != 0);
-  vector<Item*>::iterator i = find(nodes_.begin(), nodes_.end(), node);
+  vector<DrawTree::Node*>::iterator i = find(nodes_.begin(), nodes_.end(), node);
 
   g_return_if_fail(i != nodes_.end());
   
@@ -2028,7 +2048,7 @@ void
 GAptPkgTree::CategoryList::clear_nodes()
 {
   tree_->tree()->change_selection(0);
-  vector<Item*>::iterator j = nodes_.begin();
+  vector<DrawTree::Node*>::iterator j = nodes_.begin();
   while (j != nodes_.end()) {
     delete *j;
     ++j;
